==> okteta-14.11.95.tar.xz: okteta-14.11.95/kasten/gui/io/streamencoder/bytearraytextstreamencoderpreview.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "bytearraytextstreamencoderpreview.h"

// lib
#include "abstractbytearraystreamencoder.h"
// KF5
#include <KLocalizedString>
// Qt
#include <QFontDatabase>
#include <QTextEdit>

namespace Kasten
{

ByteArrayTextStreamEncoderPreview::ByteArrayTextStreamEncoderPreview( AbstractByteArrayStreamEncoder* encoder )
 : mEncoder( encoder ), mModel( 0 )
{
    mWidget = new QTextEdit(); // TODO: use Kate for syntax highlighting
    mWidget->setReadOnly( true );
    mWidget->setLineWrapMode( QTextEdit::NoWrap );
    mWidget->setToolTip( i18n("The preview uses maximal the first 100 bytes.") );

    // TODO: find a signal/event emitted when fixedfont changes
//     connect( KGlobalSettings::self(), &KGlobalSettings::kdisplayFontChanged,
//              this, &ByteArrayTextStreamEncoderPreview::setFixedFontByGlobalSettings );
    setFixedFontByGlobalSettings();

    connect( mEncoder, &AbstractByteArrayStreamEncoder::settingsChanged, this, &ByteArrayTextStreamEncoderPreview::update );
}

QWidget* ByteArrayTextStreamEncoderPreview::widget() const { return mWidget; }

void ByteArrayTextStreamEncoderPreview::setData( AbstractModel* model, const AbstractModelSelection* selection )
{
    mModel = model;
    mSelection = selection;

    update();
}


void ByteArrayTextStreamEncoderPreview::update()
{
    if( mModel )
        mWidget->setText( mEncoder->previewData(mModel,mSelection) );
}

void ByteArrayTextStreamEncoderPreview::setFixedFontByGlobalSettings()
{
    mWidget->setFont( QFontDatabase::systemFont(QFontDatabase::FixedFont) );
}

ByteArrayTextStreamEncoderPreview::~ByteArrayTextStreamEncoderPreview()
{
    delete mWidget;
}

}

==> okteta_17.12.3.orig.tar.xz: okteta-17.12.3/kasten/gui/io/streamencoder/bytearraytextstreamencoderpreview.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "bytearraytextstreamencoderpreview.h"

// lib
#include "abstractbytearraystreamencoder.h"
// KF5
#include <KLocalizedString>
// Qt
#include <QFontDatabase>
#include <QTextEdit>

namespace Kasten
{

ByteArrayTextStreamEncoderPreview::ByteArrayTextStreamEncoderPreview( AbstractByteArrayStreamEncoder* encoder )
 : mEncoder( encoder ), mModel( nullptr )
{
    mWidget = new QTextEdit(); // TODO: use Kate for syntax highlighting
    mWidget->setReadOnly( true );
    mWidget->setLineWrapMode( QTextEdit::NoWrap );
    mWidget->setToolTip( i18n("The preview uses maximal the first 100 bytes.") );

    // TODO: find a signal/event emitted when fixedfont changes
//     connect( KGlobalSettings::self(), &KGlobalSettings::kdisplayFontChanged,
//              this, &ByteArrayTextStreamEncoderPreview::setFixedFontByGlobalSettings );
    setFixedFontByGlobalSettings();

    connect( mEncoder, &AbstractByteArrayStreamEncoder::settingsChanged, this, &ByteArrayTextStreamEncoderPreview::update );
}

QWidget* ByteArrayTextStreamEncoderPreview::widget() const { return mWidget; }

void ByteArrayTextStreamEncoderPreview::setData( AbstractModel* model, const AbstractModelSelection* selection )
{
    mModel = model;
    mSelection = selection;

    update();
}


void ByteArrayTextStreamEncoderPreview::update()
{
    if( mModel )
        mWidget->setText( mEncoder->previewData(mModel,mSelection) );
}

void ByteArrayTextStreamEncoderPreview::setFixedFontByGlobalSettings()
{
    mWidget->setFont( QFontDatabase::systemFont(QFontDatabase::FixedFont) );
}

ByteArrayTextStreamEncoderPreview::~ByteArrayTextStreamEncoderPreview()
{
    delete mWidget;
}

}
